# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Version 0.0.2] - 2020-08-06

Remove graphviz as a required dependency, add the taint_output flag.

### Added

- taint_output flag

### Changed

- N/A

### Removed

- Dependency on graphviz package

[0.0.2]: https://github.com/zeropointdynamics/zelos-crashd/releases/tag/v0.0.2

## [Version 0.0.1] - 2020-08-05

Initial public release.

### Added

- Initial open source commit.

### Changed

- N/A

### Removed

- N/A

[0.0.1]: https://github.com/zeropointdynamics/zelos-crashd/releases/tag/v0.0.1